/*
	GnuJSP Toolkit - useful classes for JSP and servlet development
	Copyright (C) 1998, Vincent Partington <vinny@nmg.nl>

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package	nl.nmg.servlet;

/**
 * The HTMLEncoder class contains a utility method for converting
 * a string into a format suitable for placing inside a HTML tag
 * parameter, sometimes known as "html encoding".
 *
 * <P>To convert a <CODE>String</CODE>, each character is examined
 * in turn:
 * <UL>
 * <LI>&lt; is converted into &amp;lt;
 * <LI>&gt; is converted into &amp;gt;
 * <LI>&amp; is converted into &amp;amp;
 * <LI>&#034; is converted into &amp;#034;
 * <LI>&#039; is converted into &amp;#039;
 * <LI>All other characters remain the same.
 * </UL>
 */
public class HTMLEncoder {
	/**
	 * No public constructor
	 */
	private HTMLEncoder ()
	{
	}

	/**
	 * Converts a string into a htmlencoded string.
	 *
	 * @param val the <CODE>String</CODE> to be converted.
	 * @return the converted <CODE>String</CODE>.
	 */
	public static String encode(String val) {
		if(val != null) {
			StringBuffer	buf = new StringBuffer(val.length() + 8);
			char			c;

			for(int i = 0; i < val.length(); i++) {
				c = val.charAt(i);
				switch(c) {
				case '<':
					buf.append("&lt;");
					break;
				case '>':
					buf.append("&gt;");
					break;
				case '&':
					buf.append("&amp;");
					break;
				case '\"':
					buf.append("&#034;");
					break;
				case '\'':
					buf.append("&#039;");
					break;
				default:
					buf.append(c);
					break;
				}
			}
			return buf.toString();
		} else {
			return new String("");
		}
	}
}
